@@ -59,7 +59,7 @@ impl<'a> From<crate::FullNameRef<'a>> for FullName {
 impl FullName {
     /// Interpret this fully qualified reference name as partial name.
     pub fn to_partial(&self) -> crate::PartialNameRef<'_> {
-        crate::PartialNameRef(self.0.as_bstr())
+        crate::PartialNameRef(self.0.as_bstr().into())
     }
 
     /// Interpret this fully qualified reference as shared full name
